labeltools.label_tie_chains_in_expr_with_tie_chain_durations
============================================================

.. autofunction:: abjad.tools.labeltools.label_tie_chains_in_expr_with_tie_chain_durations.label_tie_chains_in_expr_with_tie_chain_durations
   :noindex:
